@@ -46,7 +46,7 @@ struct _MainWinClass {
 GType main_win_get_type(void);
 
 GtkWidget *main_win_new(void);
-gint main_win_run(MainWin *self);
+gint main_win_run(MainWin *self, guint32 timestamp);
 
 G_END_DECLS
 
