@@ -1,6 +1,6 @@
 /*
  *  Breeze  --  An application launcher with command-line style
- *  Copyright (C) 2005, 2006 Hironao Komatsu
+ *  Copyright (C) 2005, 2006, 2008 Hironao Komatsu
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -23,6 +23,9 @@
 extern GHashTable *user_commands;
 gboolean user_commands_changed;
 
+int insert_user_commands(gchar *keyword, gchar *command);
+gconstpointer lookup_user_commands(const gchar *keyword);
+void user_commands_table_foreach(GHFunc func, gpointer user_data);
 int load_user_commands(void);
 int save_user_commands(void);
 void free_user_commands(void);
